@@ -1,4 +1,4 @@
-__version__ = "0.0.2";
+__version__ = "0.0.3";
 
 import discord;
 import os;
@@ -15,18 +15,13 @@ class DPY:
 
   class msg:
       # SEND A MESSAGE
-    async def chansend(**kwargs):
+    async def send(msg):
       """
       sends a message to the channel.
       """
       message = DPY.__getattributes__()["message"];
 
-      if kwargs.hasattr("embed"):
-        return await message.channel.send(embed = kwargs["embed"]);
-      elif kwargs[0] != None:
-        return await message.channel.send(kwargs[0]);
-      else:
-        print("Error for not having any args here.")
+      await message.channel.send(msg);
     
       # DELETE A MESSAGE
     async def delete():
@@ -56,10 +51,6 @@ class DPY:
       args = self.get_args();
       return args[0];
 
-      
-      
-      
-  
   class Embed:
     def __init__(self, **kwargs):
       if kwargs.hasattr("description"):
@@ -78,8 +69,7 @@ class DPY:
         return discord.Embed(title = self.title, description = self.description, color = self.color);
       else:
         return discord.Embed(title = self.title, description = self.description);
-      
-    
+       
   class f_arg:
       # GET AN ID
     def getid(self, x):
